#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mod_name rjsmin
%{?sle15_python_module_pythons}
Name:           python-%{mod_name}
Version:        1.2.2
Release:        2.4
Summary:        A JavaScript minifier written in Python
License:        Apache-2.0
URL:            http://opensource.perlig.de/rjsmin/
Source:         https://github.com/ndparker/rjsmin/archive/refs/tags/%{version}.tar.gz#/rjsmin-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Obsoletes:      %{name}-doc
%python_subpackages

%description
rJSmin is a Javascript minifier written in Python.

The minifier is based on the semantics of jsmin.c by Douglas Crockford.

The module is a re-implementation targeting speed, so it can be used
at runtime (rather than during a preprocessing step).

%prep
%autosetup -p1 -n %{mod_name}-%{version}

%build
export CFLAGS="%optflags" # must be defined to build without -ftest-coverage instrumentation
%pyproject_wheel

%install
%pyproject_install
rm -rf %{buildroot}%{_datadir}/doc/rjsmin

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.md docs/CHANGES
%{python_sitearch}/rjsmin.py
%{python_sitearch}/_rjsmin*
%pycache_only %{python_sitearch}/__pycache__/rjsmin*
%{python_sitearch}/rjsmin-%{version}.dist-info

%changelog
* Mon Jan  8 2024 Bernhard Wiedemann <bwiedemann@suse.de>
- Build without devel-instrumentation
- Get reproducible builds
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 1.2.2:
  * Add musllinux wheels
  * Add support for Python 3.12
  * Update project boilerplate
- drop reproducible.patch (upstream)
* Wed Jun 21 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.2.1
  * ) Add support for Python 3.11
  * ) Removed debug print from setup.py
  * ) Update project boilerplate
* Thu Apr 14 2022 pgajdos@suse.com
- version update to 1.2.0
  * ) Improve regex detection. Fixes #17, #23
  * ) Add aarch64 wheels (issue #24, #25, contributed by odidev)
  * ) Add tests to source distribution (issue #20, contributed by dvzrv)
  * ) bytearray input now produces bytearray output
  * ) Update python support: 2.7, 3.6+
  * ) Emit the correct env var name in the warning message if the compilation of
    the C implementation fails.
- modified patches
  %% reproducible.patch (refreshed)
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Mar  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update reproducible.patch to also remove Werror from flags
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary.
* Sat May 18 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to build without profiling (boo#1040589)
* Wed May 15 2019 Ethan Apodaca <eapodaca@suse.com>
- Update to 1.1.0
  + See changes file for changes
- Add check phase to spec
- Remove documentation subpackage
* Wed Nov 15 2017 buschmann23@opensuse.org
- spec file
  + convert to single spec file
  + move docs into separate package
* Tue Jul  5 2016 aplanas@suse.com
- Add initial rJSmin version 1.0.12
